You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@qpid.apache.org by ri...@apache.org on 2007/05/09 17:20:56 UTC

svn commit: r536564 - in /incubator/qpid/trunk/qpid: ./ java/perftests/pom.xml java/perftests/src/main/java/org/apache/qpid/requestreply/PingPongProducer.java

Author: ritchiem
Date: Wed May  9 08:20:55 2007
New Revision: 536564

URL: http://svn.apache.org/viewvc?view=rev&rev=536564
Log:
Merged revisions 536483-536496 via svnmerge from 
https://svn.apache.org/repos/asf/incubator/qpid/branches/M2

........
  r536483 | rgreig | 2007-05-09 11:36:06 +0100 (Wed, 09 May 2007) | 1 line
  
  Improvements made to max pending message limit code.
........
  r536486 | rgreig | 2007-05-09 11:48:39 +0100 (Wed, 09 May 2007) | 1 line
  
  Added max buffer limits to all tests.
........
  r536496 | rgreig | 2007-05-09 13:11:51 +0100 (Wed, 09 May 2007) | 1 line
  
  Improved safety limts for message size tests.
........

Modified:
    incubator/qpid/trunk/qpid/   (props changed)
    incubator/qpid/trunk/qpid/java/perftests/pom.xml
    incubator/qpid/trunk/qpid/java/perftests/src/main/java/org/apache/qpid/requestreply/PingPongProducer.java

Propchange: incubator/qpid/trunk/qpid/
------------------------------------------------------------------------------
Binary property 'svnmerge-integrated' - no diff available.

Modified: incubator/qpid/trunk/qpid/java/perftests/pom.xml
URL: http://svn.apache.org/viewvc/incubator/qpid/trunk/qpid/java/perftests/pom.xml?view=diff&rev=536564&r1=536563&r2=536564
==============================================================================
--- incubator/qpid/trunk/qpid/java/perftests/pom.xml (original)
+++ incubator/qpid/trunk/qpid/java/perftests/pom.xml Wed May  9 08:20:55 2007
@@ -221,125 +221,124 @@
                         -->
 
                         <!-- Transient, P2P Tests -->
-                        <TQR-Qpid-1>-n TQR-Qpid-1           -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=0     </TQR-Qpid-1>
-                        <TQR-Qpid-2>-n TQR-Qpid-2           -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=0     </TQR-Qpid-2>
-                        <TQR-Qpid-3>-n TQR-Qpid-3           -d24H -s[100000] -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=100 batchSize=100000 messageSize=256     destinationsCount=1  rate=10000 </TQR-Qpid-3>
-                        <TQR-Qpid-4>-n TQR-Qpid-4           -d24H -s[100000] -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=100 batchSize=100000 messageSize=256     destinationsCount=1  rate=10000 </TQR-Qpid-4>
-
-                        <TQC-Qpid-1>-n TPC-Qpid-1           -d1M  -s[100]    -c[1,32],samples=32 -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=100   </TQC-Qpid-1>
-                        <TQC-Qpid-2>-n TPC-Qpid-2           -d1M  -s[100]    -c[1,32],samples=32 -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=100   </TQC-Qpid-2>
-                        <TQC-Qpid-7>-n TQC-Qpid-7           -d10M -s[1000]   -c[10]              -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     </TQC-Qpid-7>
-                        <TQC-Qpid-8>-n TQC-Qpid-8           -d10M -s[1000]   -c[10]              -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     </TQC-Qpid-8>
-                        <TQC-Qpid-11>-n TQC-Qpid-1          -d10M -s[1000]   -c[100]             -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     </TQC-Qpid-11>
-                        <TQC-Qpid-12>-n TQC-Qpid-12         -d10M -s[1000]   -c[100]             -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     </TQC-Qpid-12>
-
-                        <TQM-Qpid-1-512b>-n TQM-Qpid-1-512b -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=512     destinationsCount=1  rate=0     </TQM-Qpid-1-512b>
-                        <TQM-Qpid-2-512b>-n TQM-Qpid-2-512b -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=512     destinationsCount=1  rate=0     </TQM-Qpid-2-512b>
-                        <TQM-Qpid-1-1K>-n TQM-Qpid-1-1K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=1024    destinationsCount=1  rate=0     </TQM-Qpid-1-1K>
-                        <TQM-Qpid-2-1K>-n TQM-Qpid-2-1K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=1024    destinationsCount=1  rate=0     </TQM-Qpid-2-1K>
-                        <TQM-Qpid-1-5K>-n TQM-Qpid-1-5K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=5120    destinationsCount=1  rate=0     </TQM-Qpid-1-5K>
-                        <TQM-Qpid-2-5K>-n TQM-Qpid-2-5K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=5120    destinationsCount=1  rate=0     </TQM-Qpid-2-5K>
-                        <TQM-Qpid-1-10K>-n TQM-Qpid-1-10K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=10240   destinationsCount=1  rate=0     </TQM-Qpid-1-10K>
-                        <TQM-Qpid-2-10K>-n TQM-Qpid-2-10K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=10240   destinationsCount=1  rate=0     </TQM-Qpid-2-10K>
-                        <TQM-Qpid-1-50K>-n TQM-Qpid-1-50K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=51200   destinationsCount=1  rate=0     </TQM-Qpid-1-50K>
-                        <TQM-Qpid-2-50K>-n TQM-Qpid-2-50K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=51200   destinationsCount=1  rate=0     </TQM-Qpid-2-50K>
-                        <TQM-Qpid-1-100K>-n TQM-Qpid-1-100K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=102400  destinationsCount=1  rate=0     </TQM-Qpid-1-100K>
-                        <TQM-Qpid-2-100K>-n TQM-Qpid-2-100K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=102400  destinationsCount=1  rate=0     </TQM-Qpid-2-100K>
-                        <TQM-Qpid-1-500K>-n TQM-Qpid-1-500K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=512000  destinationsCount=1  rate=0     </TQM-Qpid-1-500K>
-                        <TQM-Qpid-2-500K>-n TQM-Qpid-2-500K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=512000  destinationsCount=1  rate=0     </TQM-Qpid-2-500K>
-                        <TQM-Qpid-1-1M>-n TQM-Qpid-1-1M     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=1048576 destinationsCount=1  rate=0     </TQM-Qpid-1-1M>
-                        <TQM-Qpid-2-1M>-n TQM-Qpid-2-1M     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=1048576 destinationsCount=1  rate=0     </TQM-Qpid-2-1M>
+                        <TQR-Qpid-1>-n TQR-Qpid-1           -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=0     maxPending=1000000 </TQR-Qpid-1>
+                        <TQR-Qpid-2>-n TQR-Qpid-2           -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=0     maxPending=1000000 </TQR-Qpid-2>
+                        <TQR-Qpid-3>-n TQR-Qpid-3           -d24H -s[100000] -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=100 batchSize=100000 messageSize=256     destinationsCount=1  rate=10000 maxPending=1000000 </TQR-Qpid-3>
+                        <TQR-Qpid-4>-n TQR-Qpid-4           -d24H -s[100000] -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=100 batchSize=100000 messageSize=256     destinationsCount=1  rate=10000 maxPending=1000000 </TQR-Qpid-4>
+
+                        <TQC-Qpid-1>-n TPC-Qpid-1           -d1M  -s[1000]   -c[1,32],samples=32 -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=1000  maxPending=1000000 </TQC-Qpid-1>
+                        <TQC-Qpid-2>-n TPC-Qpid-2           -d1M  -s[1000]   -c[1,32],samples=32 -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=1000  maxPending=1000000 </TQC-Qpid-2>
+                        <TQC-Qpid-7>-n TQC-Qpid-7           -d10M -s[1000]   -c[10]              -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     maxPending=1000000 </TQC-Qpid-7>
+                        <TQC-Qpid-8>-n TQC-Qpid-8           -d10M -s[1000]   -c[10]              -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     maxPending=1000000 </TQC-Qpid-8>
+                        <TQC-Qpid-11>-n TQC-Qpid-1          -d10M -s[1000]   -c[100]             -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     maxPending=1000000 </TQC-Qpid-11>
+                        <TQC-Qpid-12>-n TQC-Qpid-12         -d10M -s[1000]   -c[100]             -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     maxPending=1000000 </TQC-Qpid-12>
+
+                        <TQM-Qpid-1-512b>-n TQM-Qpid-1-512b -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=512     destinationsCount=1  rate=0     maxPending=20000000</TQM-Qpid-1-512b>
+                        <TQM-Qpid-2-512b>-n TQM-Qpid-2-512b -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=512     destinationsCount=1  rate=0     maxPending=20000000</TQM-Qpid-2-512b>
+                        <TQM-Qpid-1-1K>-n TQM-Qpid-1-1K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=1024    destinationsCount=1  rate=0     maxPending=20000000</TQM-Qpid-1-1K>
+                        <TQM-Qpid-2-1K>-n TQM-Qpid-2-1K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=1024    destinationsCount=1  rate=0     maxPending=20000000</TQM-Qpid-2-1K>
+                        <TQM-Qpid-1-5K>-n TQM-Qpid-1-5K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=5120    destinationsCount=1  rate=0     maxPending=20000000</TQM-Qpid-1-5K>
+                        <TQM-Qpid-2-5K>-n TQM-Qpid-2-5K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=5120    destinationsCount=1  rate=0     maxPending=20000000</TQM-Qpid-2-5K>
+                        <TQM-Qpid-1-10K>-n TQM-Qpid-1-10K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=10240   destinationsCount=1  rate=0     maxPending=20000000</TQM-Qpid-1-10K>
+                        <TQM-Qpid-2-10K>-n TQM-Qpid-2-10K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=10240   destinationsCount=1  rate=0     maxPending=20000000</TQM-Qpid-2-10K>
+                        <TQM-Qpid-1-50K>-n TQM-Qpid-1-50K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=51200   destinationsCount=1  rate=0     maxPending=20000000</TQM-Qpid-1-50K>
+                        <TQM-Qpid-2-50K>-n TQM-Qpid-2-50K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=51200   destinationsCount=1  rate=0     maxPending=20000000</TQM-Qpid-2-50K>
+                        <TQM-Qpid-1-100K>-n TQM-Qpid-1-100K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=102400  destinationsCount=1  rate=0     maxPending=20000000</TQM-Qpid-1-100K>
+                        <TQM-Qpid-2-100K>-n TQM-Qpid-2-100K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=102400  destinationsCount=1  rate=0     maxPending=20000000</TQM-Qpid-2-100K>
+                        <TQM-Qpid-1-500K>-n TQM-Qpid-1-500K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=512000  destinationsCount=1  rate=0     maxPending=20000000</TQM-Qpid-1-500K>
+                        <TQM-Qpid-2-500K>-n TQM-Qpid-2-500K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=512000  destinationsCount=1  rate=0     maxPending=20000000</TQM-Qpid-2-500K>
+                        <TQM-Qpid-1-1M>-n TQM-Qpid-1-1M     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=1048576 destinationsCount=1  rate=0     maxPending=20000000</TQM-Qpid-1-1M>
+                        <TQM-Qpid-2-1M>-n TQM-Qpid-2-1M     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=1048576 destinationsCount=1  rate=0     maxPending=20000000</TQM-Qpid-2-1M>
 
                         <!-- Transient, Pub/Sub Tests -->
-                        <TTR-Qpid-1>-n TTR-Qpid-1           -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=0     </TTR-Qpid-1>
-                        <TTR-Qpid-2>-n TTR-Qpid-2           -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=0     </TTR-Qpid-2>
-                        <TTR-Qpid-3>-n TTR-Qpid-3           -d24H -s[100000] -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=100 batchSize=10000  messageSize=256     destinationsCount=1  rate=10000 </TTR-Qpid-3>
-                        <TTR-Qpid-4>-n TTR-Qpid-4           -d24H -s[100000] -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=100 batchSize=10000  messageSize=256     destinationsCount=1  rate=10000 </TTR-Qpid-4>
-
-                        <TTC-Qpid-1>-n TTC-Qpid-1           -d1M  -s[1000]   -c[1,32],samples=32 -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=1000  </TTC-Qpid-1>
-                        <TTC-Qpid-2>-n TTC-Qpid-2           -d1M  -s[1000]   -c[1,32],samples=32 -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=1000  </TTC-Qpid-2>
-                        <TTC-Qpid-7>-n TTC-Qpid-7           -d10M -s[1000]   -c[10]              -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     </TTC-Qpid-7>
-                        <TTC-Qpid-8>-n TTC-Qpid-8           -d10M -s[1000]   -c[10]              -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     </TTC-Qpid-8>
-                        <TTC-Qpid-11>-n TTC-Qpid-11         -d10M -s[1000]   -c[100]             -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     </TTC-Qpid-11>
-                        <TTC-Qpid-12>-n TTC-Qpid-12         -d10M -s[1000]   -c[100]             -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     </TTC-Qpid-12>
-
-                        <TTM-Qpid-1-512b>-n TTM-Qpid-1-512b -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=512     destinationsCount=1  rate=0     </TTM-Qpid-1-512b>
-                        <TTM-Qpid-2-512b>-n TTM-Qpid-2-512b -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=512     destinationsCount=1  rate=0     </TTM-Qpid-2-512b>
-                        <TTM-Qpid-1-1K>-n TTM-Qpid-1-1K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=1024    destinationsCount=1  rate=0     </TTM-Qpid-1-1K>
-                        <TTM-Qpid-2-1K>-n TTM-Qpid-2-1K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=1024    destinationsCount=1  rate=0     </TTM-Qpid-2-1K>
-                        <TTM-Qpid-1-5K>-n TTM-Qpid-1-5K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=5120    destinationsCount=1  rate=0     </TTM-Qpid-1-5K>
-                        <TTM-Qpid-2-5K>-n TTM-Qpid-2-5K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=5120    destinationsCount=1  rate=0     </TTM-Qpid-2-5K>
-                        <TTM-Qpid-1-10K>-n TTM-Qpid-1-10K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=10240   destinationsCount=1  rate=0     </TTM-Qpid-1-10K>
-                        <TTM-Qpid-2-10K>-n TTM-Qpid-2-10K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=10240   destinationsCount=1  rate=0     </TTM-Qpid-2-10K>
-                        <TTM-Qpid-1-50K>-n TTM-Qpid-1-50K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=51200   destinationsCount=1  rate=0     </TTM-Qpid-1-50K>
-                        <TTM-Qpid-2-50K>-n TTM-Qpid-2-50K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=51200   destinationsCount=1  rate=0     </TTM-Qpid-2-50K>
-                        <TTM-Qpid-1-100K>-n TTM-Qpid-1-100K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=102400  destinationsCount=1  rate=0     </TTM-Qpid-1-100K>
-                        <TTM-Qpid-2-100K>-n TTM-Qpid-2-100K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=102400  destinationsCount=1  rate=0     </TTM-Qpid-2-100K>
-                        <TTM-Qpid-1-500K>-n TTM-Qpid-1-500K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=512000  destinationsCount=1  rate=0     </TTM-Qpid-1-500K>
-                        <TTM-Qpid-2-500K>-n TTM-Qpid-2-500K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=512000  destinationsCount=1  rate=0     </TTM-Qpid-2-500K>
-                        <TTM-Qpid-1-1M>-n TTM-Qpid-1-1M     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=1048576 destinationsCount=1  rate=0     </TTM-Qpid-1-1M>
-                        <TTM-Qpid-2-1M>-n TTM-Qpid-2-1M     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=1048476 destinationsCount=1  rate=0     </TTM-Qpid-2-1M>
+                        <TTR-Qpid-1>-n TTR-Qpid-1           -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=0     maxPending=1000000 </TTR-Qpid-1>
+                        <TTR-Qpid-2>-n TTR-Qpid-2           -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=0     maxPending=1000000 </TTR-Qpid-2>
+                        <TTR-Qpid-3>-n TTR-Qpid-3           -d24H -s[100000] -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=100 batchSize=10000  messageSize=256     destinationsCount=1  rate=10000 maxPending=1000000 </TTR-Qpid-3>
+                        <TTR-Qpid-4>-n TTR-Qpid-4           -d24H -s[100000] -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=100 batchSize=10000  messageSize=256     destinationsCount=1  rate=10000 maxPending=1000000 </TTR-Qpid-4>
+
+                        <TTC-Qpid-1>-n TTC-Qpid-1           -d1M  -s[1000]   -c[1,32],samples=32 -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=1000  maxPending=1000000 </TTC-Qpid-1>
+                        <TTC-Qpid-2>-n TTC-Qpid-2           -d1M  -s[1000]   -c[1,32],samples=32 -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=1000  maxPending=1000000 </TTC-Qpid-2>
+                        <TTC-Qpid-7>-n TTC-Qpid-7           -d10M -s[1000]   -c[10]              -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     maxPending=1000000 </TTC-Qpid-7>
+                        <TTC-Qpid-8>-n TTC-Qpid-8           -d10M -s[1000]   -c[10]              -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     maxPending=1000000 </TTC-Qpid-8>
+                        <TTC-Qpid-11>-n TTC-Qpid-11         -d10M -s[1000]   -c[100]             -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     maxPending=1000000 </TTC-Qpid-11>
+                        <TTC-Qpid-12>-n TTC-Qpid-12         -d10M -s[1000]   -c[100]             -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     maxPending=1000000 </TTC-Qpid-12>
+
+                        <TTM-Qpid-1-512b>-n TTM-Qpid-1-512b -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=10  batchSize=1000   messageSize=512     destinationsCount=1  rate=0     maxPending=20000000</TTM-Qpid-1-512b>
+                        <TTM-Qpid-2-512b>-n TTM-Qpid-2-512b -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=10  batchSize=1000   messageSize=512     destinationsCount=1  rate=0     maxPending=20000000</TTM-Qpid-2-512b>
+                        <TTM-Qpid-1-1K>-n TTM-Qpid-1-1K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=10  batchSize=1000   messageSize=1024    destinationsCount=1  rate=0     maxPending=20000000</TTM-Qpid-1-1K>
+                        <TTM-Qpid-2-1K>-n TTM-Qpid-2-1K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=10  batchSize=1000   messageSize=1024    destinationsCount=1  rate=0     maxPending=20000000</TTM-Qpid-2-1K>
+                        <TTM-Qpid-1-5K>-n TTM-Qpid-1-5K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=10  batchSize=1000   messageSize=5120    destinationsCount=1  rate=0     maxPending=20000000</TTM-Qpid-1-5K>
+                        <TTM-Qpid-2-5K>-n TTM-Qpid-2-5K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=10  batchSize=1000   messageSize=5120    destinationsCount=1  rate=0     maxPending=20000000</TTM-Qpid-2-5K>
+                        <TTM-Qpid-1-10K>-n TTM-Qpid-1-10K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=10  batchSize=1000   messageSize=10240   destinationsCount=1  rate=0     maxPending=20000000</TTM-Qpid-1-10K>
+                        <TTM-Qpid-2-10K>-n TTM-Qpid-2-10K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=10  batchSize=1000   messageSize=10240   destinationsCount=1  rate=0     maxPending=20000000</TTM-Qpid-2-10K>
+                        <TTM-Qpid-1-50K>-n TTM-Qpid-1-50K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=10  batchSize=1000   messageSize=51200   destinationsCount=1  rate=0     maxPending=20000000</TTM-Qpid-1-50K>
+                        <TTM-Qpid-2-50K>-n TTM-Qpid-2-50K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=10  batchSize=1000   messageSize=51200   destinationsCount=1  rate=0     maxPending=20000000</TTM-Qpid-2-50K>
+                        <TTM-Qpid-1-100K>-n TTM-Qpid-1-100K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=10  batchSize=1000   messageSize=102400  destinationsCount=1  rate=0     maxPending=20000000</TTM-Qpid-1-100K>
+                        <TTM-Qpid-2-100K>-n TTM-Qpid-2-100K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=10  batchSize=1000   messageSize=102400  destinationsCount=1  rate=0     maxPending=20000000</TTM-Qpid-2-100K>
+                        <TTM-Qpid-1-500K>-n TTM-Qpid-1-500K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=10  batchSize=1000   messageSize=512000  destinationsCount=1  rate=0     maxPending=20000000</TTM-Qpid-1-500K>
+                        <TTM-Qpid-2-500K>-n TTM-Qpid-2-500K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=10  batchSize=1000   messageSize=512000  destinationsCount=1  rate=0     maxPending=20000000</TTM-Qpid-2-500K>
+                        <TTM-Qpid-1-1M>-n TTM-Qpid-1-1M     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=true  commitBatchSize=10  batchSize=1000   messageSize=1048576 destinationsCount=1  rate=0     maxPending=20000000</TTM-Qpid-1-1M>
+                        <TTM-Qpid-2-1M>-n TTM-Qpid-2-1M     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=true  transacted=false commitBatchSize=10  batchSize=1000   messageSize=1048476 destinationsCount=1  rate=0     maxPending=20000000</TTM-Qpid-2-1M>
 
                         <!-- Persistent, P2P Tests -->
-                        <PQR-Qpid-1>-n PQR-Qpid-1           -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=0     </PQR-Qpid-1>
-                        <PQR-Qpid-2>-n PQR-Qpid-2           -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=0     </PQR-Qpid-2>
-                        <PQR-Qpid-3>-n PQR-Qpid-3           -d24H -s[100000] -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=100 batchSize=100000 messageSize=256     destinationsCount=1  rate=1000  </PQR-Qpid-3>
-                        <PQR-Qpid-4>-n PQR-Qpid-4           -d24H -s[100000] -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=100 batchSize=100000 messageSize=256     destinationsCount=1  rate=1000  </PQR-Qpid-4>
-
-                        <PQC-Qpid-1>-n PPC-Qpid-1           -d1M  -s[100]    -c[1,32],samples=32 -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=100   </PQC-Qpid-1>
-                        <PQC-Qpid-2>-n PPC-Qpid-2           -d1M  -s[100]    -c[1,32],samples=32 -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=100   </PQC-Qpid-2>
-                        <PQC-Qpid-7>-n PQC-Qpid-7           -d10M -s[1000]   -c[10]              -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=100 batchSize=100    messageSize=256     destinationsCount=10 rate=0     </PQC-Qpid-7>
-                        <PQC-Qpid-8>-n PQC-Qpid-8           -d10M -s[1000]   -c[10]              -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     </PQC-Qpid-8>
-                        <PQC-Qpid-11>-n PQC-Qpid-11         -d10M -s[1000]   -c[100]             -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     </PQC-Qpid-11>
-                        <PQC-Qpid-12>-n PQC-Qpid-12         -d10M -s[1000]   -c[100]             -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     </PQC-Qpid-12>
-
-                        <PQM-Qpid-1-512b>-n PQM-Qpid-1-512b -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=512     destinationsCount=1  rate=0     </PQM-Qpid-1-512b>
-                        <PQM-Qpid-2-512b>-n PQM-Qpid-2-512b -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=512     destinationsCount=1  rate=0     </PQM-Qpid-2-512b>
-                        <PQM-Qpid-1-1K>-n PQM-Qpid-1-1K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=1024    destinationsCount=1  rate=0     </PQM-Qpid-1-1K>
-                        <PQM-Qpid-2-1K>-n PQM-Qpid-2-1K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=1024    destinationsCount=1  rate=0     </PQM-Qpid-2-1K>
-                        <PQM-Qpid-1-5K>-n PQM-Qpid-1-5K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=5120    destinationsCount=1  rate=0     </PQM-Qpid-1-5K>
-                        <PQM-Qpid-2-5K>-n PQM-Qpid-2-5K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=5120    destinationsCount=1  rate=0     </PQM-Qpid-2-5K>
-                        <PQM-Qpid-1-10K>-n PQM-Qpid-1-10K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=10240   destinationsCount=1  rate=0     </PQM-Qpid-1-10K>
-                        <PQM-Qpid-2-10K>-n PQM-Qpid-2-10K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=10240   destinationsCount=1  rate=0     </PQM-Qpid-2-10K>
-                        <PQM-Qpid-1-50K>-n PQM-Qpid-1-50K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=51200   destinationsCount=1  rate=0     </PQM-Qpid-1-50K>
-                        <PQM-Qpid-2-50K>-n PQM-Qpid-2-50K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=51200   destinationsCount=1  rate=0     </PQM-Qpid-2-50K>
-                        <PQM-Qpid-1-100K>-n PQM-Qpid-1-100K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=102400  destinationsCount=1  rate=0     </PQM-Qpid-1-100K>
-                        <PQM-Qpid-2-100K>-n PQM-Qpid-2-100K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=102400  destinationsCount=1  rate=0     </PQM-Qpid-2-100K>
-                        <PQM-Qpid-1-500K>-n PQM-Qpid-1-500K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=512000  destinationsCount=1  rate=0     </PQM-Qpid-1-500K>
-                        <PQM-Qpid-2-500K>-n PQM-Qpid-2-500K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=512000  destinationsCount=1  rate=0     </PQM-Qpid-2-500K>
-                        <PQM-Qpid-1-1M>-n PQM-Qpid-1-1M     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=1048576 destinationsCount=1  rate=0     </PQM-Qpid-1-1M>
-                        <PQM-Qpid-2-1M>-n PQM-Qpid-2-1M     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=1048576 destinationsCount=1  rate=0     </PQM-Qpid-2-1M>
+                        <PQR-Qpid-1>-n PQR-Qpid-1           -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=0     maxPending=1000000 </PQR-Qpid-1>
+                        <PQR-Qpid-2>-n PQR-Qpid-2           -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=0     maxPending=1000000 </PQR-Qpid-2>
+                        <PQR-Qpid-3>-n PQR-Qpid-3           -d24H -s[100000] -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=100 batchSize=100000 messageSize=256     destinationsCount=1  rate=1000  maxPending=1000000 </PQR-Qpid-3>
+                        <PQR-Qpid-4>-n PQR-Qpid-4           -d24H -s[100000] -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=100 batchSize=100000 messageSize=256     destinationsCount=1  rate=1000  maxPending=1000000 </PQR-Qpid-4>
+
+                        <PQC-Qpid-1>-n PPC-Qpid-1           -d1M  -s[100]    -c[1,32],samples=32 -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=100   maxPending=1000000 </PQC-Qpid-1>
+                        <PQC-Qpid-2>-n PPC-Qpid-2           -d1M  -s[100]    -c[1,32],samples=32 -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=100   maxPending=1000000 </PQC-Qpid-2>
+                        <PQC-Qpid-7>-n PQC-Qpid-7           -d10M -s[1000]   -c[10]              -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=100 batchSize=100    messageSize=256     destinationsCount=10 rate=0     maxPending=1000000 </PQC-Qpid-7>
+                        <PQC-Qpid-8>-n PQC-Qpid-8           -d10M -s[1000]   -c[10]              -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     maxPending=1000000 </PQC-Qpid-8>
+                        <PQC-Qpid-11>-n PQC-Qpid-11         -d10M -s[1000]   -c[100]             -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     maxPending=1000000 </PQC-Qpid-11>
+                        <PQC-Qpid-12>-n PQC-Qpid-12         -d10M -s[1000]   -c[100]             -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     maxPending=1000000 </PQC-Qpid-12>
+
+                        <PQM-Qpid-1-512b>-n PQM-Qpid-1-512b -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=512     destinationsCount=1  rate=0     maxPending=20000000</PQM-Qpid-1-512b>
+                        <PQM-Qpid-2-512b>-n PQM-Qpid-2-512b -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=512     destinationsCount=1  rate=0     maxPending=20000000</PQM-Qpid-2-512b>
+                        <PQM-Qpid-1-1K>-n PQM-Qpid-1-1K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=1024    destinationsCount=1  rate=0     maxPending=20000000</PQM-Qpid-1-1K>
+                        <PQM-Qpid-2-1K>-n PQM-Qpid-2-1K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=1024    destinationsCount=1  rate=0     maxPending=20000000</PQM-Qpid-2-1K>
+                        <PQM-Qpid-1-5K>-n PQM-Qpid-1-5K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=5120    destinationsCount=1  rate=0     maxPending=20000000</PQM-Qpid-1-5K>
+                        <PQM-Qpid-2-5K>-n PQM-Qpid-2-5K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=5120    destinationsCount=1  rate=0     maxPending=20000000</PQM-Qpid-2-5K>
+                        <PQM-Qpid-1-10K>-n PQM-Qpid-1-10K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=10240   destinationsCount=1  rate=0     maxPending=20000000</PQM-Qpid-1-10K>
+                        <PQM-Qpid-2-10K>-n PQM-Qpid-2-10K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=10240   destinationsCount=1  rate=0     maxPending=20000000</PQM-Qpid-2-10K>
+                        <PQM-Qpid-1-50K>-n PQM-Qpid-1-50K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=51200   destinationsCount=1  rate=0     maxPending=20000000</PQM-Qpid-1-50K>
+                        <PQM-Qpid-2-50K>-n PQM-Qpid-2-50K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=51200   destinationsCount=1  rate=0     maxPending=20000000</PQM-Qpid-2-50K>
+                        <PQM-Qpid-1-100K>-n PQM-Qpid-1-100K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=102400  destinationsCount=1  rate=0     maxPending=20000000</PQM-Qpid-1-100K>
+                        <PQM-Qpid-2-100K>-n PQM-Qpid-2-100K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=102400  destinationsCount=1  rate=0     maxPending=20000000</PQM-Qpid-2-100K>
+                        <PQM-Qpid-1-500K>-n PQM-Qpid-1-500K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=512000  destinationsCount=1  rate=0     maxPending=20000000</PQM-Qpid-1-500K>
+                        <PQM-Qpid-2-500K>-n PQM-Qpid-2-500K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=512000  destinationsCount=1  rate=0     maxPending=20000000</PQM-Qpid-2-500K>
+                        <PQM-Qpid-1-1M>-n PQM-Qpid-1-1M     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=1048576 destinationsCount=1  rate=0     maxPending=20000000</PQM-Qpid-1-1M>
+                        <PQM-Qpid-2-1M>-n PQM-Qpid-2-1M     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=1048576 destinationsCount=1  rate=0     maxPending=20000000</PQM-Qpid-2-1M>
 
                         <!-- Persistent, Pub/Sub Tests -->
-                        <PTR-Qpid-1>-n PTR-Qpid-1           -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=0     </PTR-Qpid-1>
-                        <PTR-Qpid-2>-n PTR-Qpid-2           -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=0     </PTR-Qpid-2>
-                        <PTR-Qpid-3>-n PTR-Qpid-3           -d24H -s[100000] -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=100 batchSize=10000  messageSize=256     destinationsCount=1  rate=1000  </PTR-Qpid-3>
-                        <PTR-Qpid-4>-n PTR-Qpid-4           -d24H -s[100000] -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=100 batchSize=10000  messageSize=256     destinationsCount=1  rate=1000  </PTR-Qpid-4>
-
-                        <PTC-Qpid-1>-n PTC-Qpid-1           -d1M  -s[1000]   -c[1,32],samples=32 -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=1000  </PTC-Qpid-1>
-                        <PTC-Qpid-2>-n PTC-Qpid-2           -d1M  -s[1000]   -c[1,32],samples=32 -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=1000  </PTC-Qpid-2>
-
-                        <PTC-Qpid-7>-n PTC-Qpid-7           -d10M -s[1000]   -c[10]              -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     </PTC-Qpid-7>
-                        <PTC-Qpid-8>-n PTC-Qpid-8           -d10M -s[1000]   -c[10]              -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     </PTC-Qpid-8>
-                        <PTC-Qpid-11>-n PTC-Qpid-11         -d10M -s[1000]   -c[100]             -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     </PTC-Qpid-11>
-                        <PTC-Qpid-12>-n PTC-Qpid-12         -d10M -s[1000]   -c[100]             -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     </PTC-Qpid-12>
-
-                        <PMT-Qpid-1-512b>-n PMT-Qpid-1-512b -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=512     destinationsCount=1  rate=0     </PMT-Qpid-1-512b>
-                        <PMT-Qpid-2-512b>-n PMT-Qpid-2-512b -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=512     destinationsCount=1  rate=0     </PMT-Qpid-2-512b>
-                        <PMT-Qpid-1-1K>-n PMT-Qpid-1-1K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=1024    destinationsCount=1  rate=0     </PMT-Qpid-1-1K>
-                        <PMT-Qpid-2-1K>-n PMT-Qpid-2-1K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=1024    destinationsCount=1  rate=0     </PMT-Qpid-2-1K>
-                        <PMT-Qpid-1-5K>-n PMT-Qpid-1-5K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=5120    destinationsCount=1  rate=0     </PMT-Qpid-1-5K>
-                        <PMT-Qpid-2-5K>-n PMT-Qpid-2-5K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=5120    destinationsCount=1  rate=0     </PMT-Qpid-2-5K>
-                        <PMT-Qpid-1-10K>-n PMT-Qpid-1-10K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=10240   destinationsCount=1  rate=0     </PMT-Qpid-1-10K>
-                        <PMT-Qpid-2-10K>-n PMT-Qpid-2-10K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=10240   destinationsCount=1  rate=0     </PMT-Qpid-2-10K>
-                        <PMT-Qpid-1-50K>-n PMT-Qpid-1-50K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=51200   destinationsCount=1  rate=0     </PMT-Qpid-1-50K>
-                        <PMT-Qpid-2-50K>-n PMT-Qpid-2-50K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=51200   destinationsCount=1  rate=0     </PMT-Qpid-2-50K>
-                        <PMT-Qpid-1-100K>-n PMT-Qpid-1-100K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=102400  destinationsCount=1  rate=0     </PMT-Qpid-1-100K>
-                        <PMT-Qpid-2-100K>-n PMT-Qpid-2-100K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=102400  destinationsCount=1  rate=0     </PMT-Qpid-2-100K>
-                        <PMT-Qpid-1-500K>-n PMT-Qpid-1-500K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=512000  destinationsCount=1  rate=0     </PMT-Qpid-1-500K>
-                        <PMT-Qpid-2-500K>-n PMT-Qpid-2-500K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=512000  destinationsCount=1  rate=0     </PMT-Qpid-2-500K>
-                        <PMT-Qpid-1-1M>-n PMT-Qpid-1-1M     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=1048576 destinationsCount=1  rate=0     </PMT-Qpid-1-1M>
-                        <PMT-Qpid-2-1M>-n PMT-Qpid-2-1M     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=1048476 destinationsCount=1  rate=0     </PMT-Qpid-2-1M>
+                        <PTR-Qpid-1>-n PTR-Qpid-1           -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=0     maxPending=1000000 </PTR-Qpid-1>
+                        <PTR-Qpid-2>-n PTR-Qpid-2           -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=0     maxPending=1000000 </PTR-Qpid-2>
+                        <PTR-Qpid-3>-n PTR-Qpid-3           -d24H -s[100000] -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=100 batchSize=10000  messageSize=256     destinationsCount=1  rate=1000  maxPending=1000000 </PTR-Qpid-3>
+                        <PTR-Qpid-4>-n PTR-Qpid-4           -d24H -s[100000] -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=100 batchSize=10000  messageSize=256     destinationsCount=1  rate=1000  maxPending=1000000 </PTR-Qpid-4>
+
+                        <PTC-Qpid-1>-n PTC-Qpid-1           -d1M  -s[100]    -c[1,32],samples=32 -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=100   maxPending=1000000 </PTC-Qpid-1>
+                        <PTC-Qpid-2>-n PTC-Qpid-2           -d1M  -s[100]    -c[1,32],samples=32 -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=1  rate=100   maxPending=1000000 </PTC-Qpid-2>
+                        <PTC-Qpid-7>-n PTC-Qpid-7           -d10M -s[1000]   -c[10]              -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     maxPending=1000000 </PTC-Qpid-7>
+                        <PTC-Qpid-8>-n PTC-Qpid-8           -d10M -s[1000]   -c[10]              -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     maxPending=1000000 </PTC-Qpid-8>
+                        <PTC-Qpid-11>-n PTC-Qpid-11         -d10M -s[1000]   -c[100]             -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     maxPending=1000000 </PTC-Qpid-11>
+                        <PTC-Qpid-12>-n PTC-Qpid-12         -d10M -s[1000]   -c[100]             -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=100 batchSize=1000   messageSize=256     destinationsCount=10 rate=0     maxPending=1000000 </PTC-Qpid-12>
+
+                        <PTM-Qpid-1-512b>-n PTM-Qpid-1-512b -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=10  batchSize=1000   messageSize=512     destinationsCount=1  rate=0     maxPending=20000000</PTM-Qpid-1-512b>
+                        <PTM-Qpid-2-512b>-n PTM-Qpid-2-512b -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=10  batchSize=1000   messageSize=512     destinationsCount=1  rate=0     maxPending=20000000</PTM-Qpid-2-512b>
+                        <PTM-Qpid-1-1K>-n PTM-Qpid-1-1K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=10  batchSize=1000   messageSize=1024    destinationsCount=1  rate=0     maxPending=20000000</PTM-Qpid-1-1K>
+                        <PTM-Qpid-2-1K>-n PTM-Qpid-2-1K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=10  batchSize=1000   messageSize=1024    destinationsCount=1  rate=0     maxPending=20000000</PTM-Qpid-2-1K>
+                        <PTM-Qpid-1-5K>-n PTM-Qpid-1-5K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=10  batchSize=1000   messageSize=5120    destinationsCount=1  rate=0     maxPending=20000000</PTM-Qpid-1-5K>
+                        <PTM-Qpid-2-5K>-n PTM-Qpid-2-5K     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=10  batchSize=1000   messageSize=5120    destinationsCount=1  rate=0     maxPending=20000000</PTM-Qpid-2-5K>
+                        <PTM-Qpid-1-10K>-n PTM-Qpid-1-10K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=10  batchSize=1000   messageSize=10240   destinationsCount=1  rate=0     maxPending=20000000</PTM-Qpid-1-10K>
+                        <PTM-Qpid-2-10K>-n PTM-Qpid-2-10K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=10  batchSize=1000   messageSize=10240   destinationsCount=1  rate=0     maxPending=20000000</PTM-Qpid-2-10K>
+                        <PTM-Qpid-1-50K>-n PTM-Qpid-1-50K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=10  batchSize=1000   messageSize=51200   destinationsCount=1  rate=0     maxPending=20000000</PTM-Qpid-1-50K>
+                        <PTM-Qpid-2-50K>-n PTM-Qpid-2-50K   -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=10  batchSize=1000   messageSize=51200   destinationsCount=1  rate=0     maxPending=20000000</PTM-Qpid-2-50K>
+                        <PTM-Qpid-1-100K>-n PTM-Qpid-1-100K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=10  batchSize=1000   messageSize=102400  destinationsCount=1  rate=0     maxPending=20000000</PTM-Qpid-1-100K>
+                        <PTM-Qpid-2-100K>-n PTM-Qpid-2-100K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=10  batchSize=1000   messageSize=102400  destinationsCount=1  rate=0     maxPending=20000000</PTM-Qpid-2-100K>
+                        <PTM-Qpid-1-500K>-n PTM-Qpid-1-500K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=10  batchSize=1000   messageSize=512000  destinationsCount=1  rate=0     maxPending=20000000</PTM-Qpid-1-500K>
+                        <PTM-Qpid-2-500K>-n PTM-Qpid-2-500K -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=10  batchSize=1000   messageSize=512000  destinationsCount=1  rate=0     maxPending=20000000</PTM-Qpid-2-500K>
+                        <PTM-Qpid-1-1M>-n PTM-Qpid-1-1M     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=true  commitBatchSize=10  batchSize=1000   messageSize=1048576 destinationsCount=1  rate=0     maxPending=20000000</PTM-Qpid-1-1M>
+                        <PTM-Qpid-2-1M>-n PTM-Qpid-2-1M     -d10M -s[1000]   -c[1]               -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=true  transacted=false commitBatchSize=10  batchSize=1000   messageSize=1048476 destinationsCount=1  rate=0     maxPending=20000000</PTM-Qpid-2-1M>
 
                         <!-- Failover Tests. -->
                         <FT-Qpid-1>-n FT-Qpid-1 -s [250000] -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf messageSize=256 batchSize=10000 transacted=true broker="tcp://10.0.0.1:5001;tcp://10.0.0.2:5002" failBeforeSend=true -o $QPID_WORK/results</FT-Qpid-1>

Modified: incubator/qpid/trunk/qpid/java/perftests/src/main/java/org/apache/qpid/requestreply/PingPongProducer.java
URL: http://svn.apache.org/viewvc/incubator/qpid/trunk/qpid/java/perftests/src/main/java/org/apache/qpid/requestreply/PingPongProducer.java?view=diff&rev=536564&r1=536563&r2=536564
==============================================================================
--- incubator/qpid/trunk/qpid/java/perftests/src/main/java/org/apache/qpid/requestreply/PingPongProducer.java (original)
+++ incubator/qpid/trunk/qpid/java/perftests/src/main/java/org/apache/qpid/requestreply/PingPongProducer.java Wed May  9 08:20:55 2007
@@ -98,7 +98,7 @@
  *                                               3 - DUPS_OK_ACKNOWLEDGE
  *                                               257 - NO_ACKNOWLEDGE
  *                                               258 - PRE_ACKNOWLEDGE
- * <tr><td> maxPending       <td> 0        <td> The maximum size in bytes, of messages send but not yet received.
+ * <tr><td> maxPending       <td> 0        <td> The maximum size in bytes, of messages sent but not yet received.
  *                                              Limits the volume of messages currently buffered on the client
  *                                              or broker. Can help scale test clients by limiting amount of buffered
  *                                              data to avoid out of memory errors.
@@ -373,10 +373,10 @@
     protected int _maxPendingSize;
 
     /**
      * Holds a cyclic barrier which is used to synchronize sender and receiver threads, where the sender has elected
      * to wait until the number of unreceived message is reduced before continuing to send.
      */
-    protected CyclicBarrier _sendPauseBarrier = new CyclicBarrier(2);
+    protected Object _sendPauseMonitor = new Object();
 
     /** Keeps a count of the number of message currently sent but not received. */
     protected AtomicInteger _unreceived = new AtomicInteger(0);
@@ -801,23 +801,27 @@
                     int unreceivedSize = (unreceived * ((_messageSize == 0) ? 1 : _messageSize));
 
                     // Release a waiting sender if there is one.
-                    if ((_maxPendingSize > 0) && (unreceivedSize < _maxPendingSize)
-                            && (_sendPauseBarrier.getNumberWaiting() == 1))
+                    synchronized (_sendPauseMonitor)
                     {
-                        log.debug("unreceived size estimate under limit = " + unreceivedSize);
-
-                        // Wait on the send pause barrier for the limit to be re-established.
-                        try
-                        {
-                            _sendPauseBarrier.await();
-                        }
-                        catch (InterruptedException e)
+                        if ((_maxPendingSize > 0) && (unreceivedSize < _maxPendingSize))
+                        // && (_sendPauseBarrier.getNumberWaiting() == 1))
                         {
-                            throw new RuntimeException(e);
-                        }
-                        catch (BrokenBarrierException e)
-                        {
-                            throw new RuntimeException(e);
+                            log.debug("unreceived size estimate under limit = " + unreceivedSize);
+
+                            // Wait on the send pause barrier for the limit to be re-established.
+                            /*try
+                            {*/
+                            // _sendPauseBarrier.await();
+                            _sendPauseMonitor.notify();
+                            /*}
+                            catch (InterruptedException e)
+                            {
+                                throw new RuntimeException(e);
+                            }
+                            catch (BrokenBarrierException e)
+                            {
+                                throw new RuntimeException(e);
+                            }*/
                         }
                     }
 
@@ -1052,26 +1056,40 @@
             waitForUser(KILL_BROKER_PROMPT);
         }
 
-        // Increase the count of sent but not yet received messages.
-        int unreceived = _unreceived.getAndIncrement();
-        int unreceivedSize = (unreceived * ((_messageSize == 0) ? 1 : _messageSize));
-
-        if ((_maxPendingSize > 0) && (unreceivedSize > _maxPendingSize))
+        // If necessary, wait until the max pending message size comes within its limit.
+        synchronized (_sendPauseMonitor)
         {
-            log.debug("unreceived size estimate over limit = " + unreceivedSize);
-
-            // Wait on the send pause barrier for the limit to be re-established.
-            try
-            {
-                _sendPauseBarrier.await();
-            }
-            catch (InterruptedException e)
+            while ((_maxPendingSize > 0))
             {
-                throw new RuntimeException(e);
-            }
-            catch (BrokenBarrierException e)
-            {
-                throw new RuntimeException(e);
+                // Get the size estimate of sent but not yet received messages.
+                int unreceived = _unreceived.get();
+                int unreceivedSize = (unreceived * ((_messageSize == 0) ? 1 : _messageSize));
+
+                if (unreceivedSize > _maxPendingSize)
+                {
+                    log.debug("unreceived size estimate over limit = " + unreceivedSize);
+
+                    // Wait on the send pause barrier for the limit to be re-established.
+                    try
+                    {
+                        // _sendPauseBarrier.await();
+                        _sendPauseMonitor.wait(1000);
+                    }
+                    catch (InterruptedException e)
+                    {
+                        // Restore the interrupted status
+                        Thread.currentThread().interrupt();
+                        throw new RuntimeException(e);
+                    }
+                    /*catch (BrokenBarrierException e)
+                    {
+                        throw new RuntimeException(e);
+                    }*/
+                }
+                else
+                {
+                    break;
+                }
             }
         }
 
@@ -1085,6 +1103,9 @@
             _producer.send(destination, message);
         }
 
+        // Increase the unreceived size, this may actually happen aftern the message is recevied.
+        _unreceived.getAndIncrement();
+
         // Apply message rate throttling if a rate limit has been set up.
         if (_rateLimiter != null)
         {
@@ -1300,6 +1321,7 @@
      * @return <tt>true</tt> if the session was committed, <tt>false</tt> if it was not.
      *
      * @throws javax.jms.JMSException If the commit fails and then the rollback fails.
+     *
      * @todo Consider moving the fail after send logic into the send method. It is confusing to have it in this commit
      * method, because commits only apply to transactional pingers, but fail after send applied to transactional and
      * non-transactional alike.
@@ -373,10 +373,10 @@
 
     /**
-     * Holds a cyclic barrier which is used to synchronize sender and receiver threads, where the sender has elected
+     * Holds a monitor which is used to synchronize sender and receiver threads, where the sender has elected
      * to wait until the number of unreceived message is reduced before continuing to send.
      */